@@ -17,7 +17,8 @@ st_agr = function(x, ...) UseMethod("st_agr")
 
 #' @export
 st_agr.sf = function(x, ...) {
-	nm = setdiff(names(x), attr(x, "sf_column"))
+	sfc_s = sapply(x, inherits, "sfc")
+	nm = names(x)[!sfc_s]
 	ret = attr(x, "agr")[nm]
 	if (is.null(names(ret)) || all(is.na(names(ret))))
 		structure(rep(NA_agr_, length(nm)), names = nm)
@@ -37,8 +38,9 @@ st_agr.factor = function(x, ...) {
 }
 
 #' @export
-st_agr.default = function(x = NA_character_, ...) { 
-	stopifnot(all(is.na(x)))
+st_agr.default = function(x = NA_character_, ...) {
+	if (is.data.frame(x) && !is.null(attr(x, "agr")))
+		x = attr(x, "agr")
 	structure(st_agr(as.character(x)), names = names(x))
 }
 
@@ -50,7 +52,9 @@ st_agr.default = function(x = NA_character_, ...) {
 #' @export
 `st_agr<-.sf` = function(x, value) {
 	stopifnot(is.character(value) || is.factor(value))
-	nv = setdiff(names(x), attr(x, "sf_column"))
+	sfc_s = sapply(x, inherits, "sfc")
+	# nv = setdiff(names(x), attr(x, "sf_column"))
+	nv = names(x)[!sfc_s]
 	if (length(value) == 0)
 		attr(x, "agr") = setNames(NA_agr_[0], character())
 	else if (! is.null(names(value)) && length(value) == 1) { 
@@ -60,13 +64,15 @@ st_agr.default = function(x = NA_character_, ...) {
 		else
 			attr(x, "agr") = st_agr(value)
 	} else {
-		value = rep(st_agr(value), length.out = ncol(x) - 1)
+		value = rep(st_agr(value), length.out = length(nv))
 		if (! is.null(names(value)))
 			value = value[match(nv, names(value))]
 		else
 			names(value) = nv
 		attr(x, "agr") <- value
 	}
+ 	#print(paste("vars: ", paste(nv, collapse=","), "value(s):", paste(value, collapse = ",")))
+ 	#print(rlang::trace_back())
 #	a = st_agr(x)
 #	absent = setdiff(names(x), c(na.omit(names(a)), attr(x, "sf_column")))
 #	if (length(absent)) { # repair:
@@ -80,14 +86,22 @@ st_agr.default = function(x = NA_character_, ...) {
 #' @name st_agr
 #' @export
 st_set_agr = function(x, value) { 
-	st_agr(x) = value
+	if (!missing(value))
+		st_agr(x) = value
+	else { # needs repair?
+		value = st_agr(x)
+		if (any(is.na(names(value))) && length(value) == length(x) - 1) {
+			names(value) = setdiff(names(x), attr(x, "sf_column"))
+			st_agr(x) = value
+		}
+	}
 	x
 }
 
 summarize_agr = function(x) {
 	su = summary(st_agr(x))
 	su = su[su > 0]
-	paste(paste0(names(su), " (", su, ")"), collapse = ", ")
+	paste0(names(su), " (", su, ")", collapse = ", ")
 }
 
 all_constant = function(x) {
