@@ -132,7 +132,8 @@ st_cast_sfc_default = function(x) {
 
 copy_sfc_attributes_from = function(x, ret) {
 	structure(ret, precision = attr(x, "precision"),
-		bbox = attr(x, "bbox"), crs = attr(x, "crs"), n_empty = attr(x, "n_empty"))
+		bbox = attr(x, "bbox"), crs = attr(x, "crs"), n_empty = attr(x, "n_empty"), 
+		z_range = attr(x, "z_range"), m_range = attr(x, "m_range"))
 }
 
 empty_sfg <- function(to) {
@@ -175,9 +176,13 @@ is_exotic = function(x) {
 #' st_cast(d, "POINT") # will not convert the entire MULTIPOINT, and warns
 #' st_cast(d, "MULTIPOINT") %>% st_cast("POINT")
 st_cast.sfc = function(x, to, ..., ids = seq_along(x), group_or_split = TRUE) {
-	if (missing(to) || length(x) == 0)
+
+	if (missing(to))
 		return(st_cast_sfc_default(x))
 
+	if (length(x) == 0) # empty set
+		return(structure(x, class = c(paste0("sfc_", to), "sfc")))
+
 	e = rep(FALSE, length(x))
 	if (!is_exotic(x)) { # for which GEOS has no st_is_empty()
 		e = st_is_empty(x)
