@@ -376,6 +376,8 @@ plot.sfc_POINT = function(x, y, ..., pch = 1, cex = 1, col = 1, bg = 0, lwd = 1,
 	if (! add)
 		plot_sf(x, ...)
 	npts = length(x)
+	if (npts == 0)
+		return()
 	pch = rep(pch, length.out = npts)
 	col = rep(col, length.out = npts)
 	bg = rep(bg, length.out = npts)
@@ -397,6 +399,8 @@ plot.sfc_MULTIPOINT = function(x, y, ..., pch = 1, cex = 1, col = 1, bg = 0, lwd
 	if (! add)
 		plot_sf(x, ...)
 	n = length(x)
+	if (n == 0)
+		return()
 	pch = rep(pch, length.out = n)
 	col = rep(col, length.out = n)
 	bg = rep(bg, length.out = n)
