@@ -20,7 +20,7 @@ format.sfc = function(x, ..., width = 30) {
 #'
 #' @name sfc
 #' @aliases sfc_POINT sfc_LINESTRING sfc_POLYGON sfc_MULTIPOINT sfc_MULTILINESTRING sfc_MULTIPOLYGON sfc_GEOMETRYCOLLECTION
-#' @param ... zero or more simple feature geometries (objects of class \code{sfg}), or a single list of such objects; \code{NULL} values will get replaced by empty geometries.
+#' @param ... input: zero or more simple feature geometries (objects of class \code{sfg}), or a single list of such objects; \code{NULL} values will get replaced by empty geometries.
 #' @param crs coordinate reference system: integer with the EPSG code, or character with proj4string
 #' @param precision numeric; see \link{st_as_binary}
 #' @param check_ring_dir see \link{st_read}
@@ -28,6 +28,7 @@ format.sfc = function(x, ..., width = 30) {
 #' @param recompute_bbox logical; use \code{TRUE} to force recomputation of the bounding box
 #' @param oriented logical; if \code{TRUE}, the ring is oriented such that left of the edges is inside the polygon; this is
 #' needed for convering polygons larger than half the globe to s2
+#' @param fall_back_class character; class for return object when no geometries are provided as input
 #' @return an object of class \code{sfc}, which is a classed list-column with simple feature geometries.
 #'
 #' @details A simple feature geometry list-column is a list of class
@@ -42,7 +43,7 @@ format.sfc = function(x, ..., width = 30) {
 #' d = st_sf(data.frame(a=1:2, geom=sfc))
 #' @export
 st_sfc = function(..., crs = NA_crs_, precision = 0.0, check_ring_dir = FALSE, dim,
-				  recompute_bbox = FALSE, oriented = NA) {
+				  recompute_bbox = FALSE, oriented = NA, fall_back_class = c("sfc_GEOMETRY", "sfc")) {
 	lst = list(...)
 	# if we have only one arg, which is already a list with sfg's, but NOT a geometrycollection:
 	# (this is the old form of calling st_sfc; it is way faster to call st_sfc(lst) if lst
@@ -63,8 +64,8 @@ st_sfc = function(..., crs = NA_crs_, precision = 0.0, check_ring_dir = FALSE, d
 
 	dims_and_types = sfc_unique_sfg_dims_and_types(lst)
 	
-	cls = if (length(lst) == 0) # empty set: no geometries read
-			c("sfc_GEOMETRY", "sfc")
+	cls = if (length(lst) == 0) # empty set: no geometries to learn from
+			fall_back_class
 		else {
 			# class: do we have a mix of geometry types?
 			single = if (!is.null(attr(lst, "single_type"))) # set by CPL_read_wkb:
@@ -129,8 +130,9 @@ st_sfc = function(..., crs = NA_crs_, precision = 0.0, check_ring_dir = FALSE, d
 	st_crs(lst) = crs
 
 	# set classes attr in case of GEOMETRY
-	if (inherits(lst, "sfc_GEOMETRY")) # recompute, as NULL's may have been substituted:
-		attr(lst, "classes") = vapply(lst, class, rep(NA_character_, 3))[2L,]
+	attr(lst, "classes") = if (inherits(lst, "sfc_GEOMETRY")) # recompute, as NULL's may have been substituted:
+		vapply(lst, class, rep(NA_character_, 3))[2L,]
+		# else NULL: removes when present; #2567
 
 	# set n_empty, check XY* is uniform:
 	if (is.null(attr(lst, "n_empty")) || any(is_null)) { # n_empty is set by CPL_read_wkb:
@@ -158,12 +160,9 @@ st_sfc = function(..., crs = NA_crs_, precision = 0.0, check_ring_dir = FALSE, d
 	precision = st_precision(x)
 	crs = st_crs(x)
 	dim = if (length(x)) class(x[[1]])[1] else "XY"
-	if (!missing(i) && (inherits(i, c("sf", "sfc", "sfg"))))
+	if (!missing(i) && inherits(i, c("sf", "sfc", "sfg")))
 		i = lengths(op(x, i, ...)) != 0
-	if (!is.null(dim(x))) # x is an array with geometries
-		st_sfc(NextMethod(), crs = crs, precision = precision, dim = dim)
-	else # x is a list but avoid NextMethod() to allow j, ... to be specified & ignored:
-		st_sfc(unclass(x)[i], crs = crs, precision = precision, dim = dim)
+	st_sfc(unclass(x)[i], crs = crs, precision = precision, dim = dim, fall_back_class = class(x))
 }
 
 #' @export
@@ -211,8 +210,9 @@ print.sfc = function(x, ..., n = 5L, what = "Geometry set for", append = "") {
 	if (!is.null(dim(x)))
 		cat(paste0(" [dim: ", paste(dim(x), collapse = " x "), "]"))
 	cat("\n")
-	if (length(x)) {
+	if (length(x) || !inherits(x, "sfc_GEOMETRY"))
 		cat(paste0("Geometry type: ", cls, "\n"))
+	if (length(x)) {
 		u = sort(unique(sapply(x, function(x) class(x)[1])))
 		cat(paste0("Dimension:     ", paste(u, collapse = ", "), "\n"))
 	}
@@ -658,3 +658,30 @@ st_is_full.sf = function(x, ...) {
 st_is_full.bbox = function(x, ...) {
 	isTRUE(sf_use_s2() && st_is_longlat(x) && all(x == c(-180,-90,180,90)))
 }
+
+#' @export
+unique.sfc = function(x, ...) {
+	st_sfc(unique(unclass(x),...), crs = st_crs(x), precision = st_precision(x))
+}
+
+#' @export
+xtfrm.sfc = function(x) {
+	d = st_dimension(x, FALSE)
+	ne = !st_is_empty(x)
+	v = vector("double", length(x))
+	if (0 %in% d)
+		v[d == 0] = 0 # or # of pts in MULTIPOINT?
+	if (1 %in% d) {
+		l = st_length(x[d == 1])
+		if (max(l) > 1)
+			l = l / max(l)
+		v[d == 1] = l
+	}
+	if (2 %in% d) {
+		a = st_area(x[d == 2])
+		if (max(a) > 1)
+			a = a / max(a)
+		v[d == 2] = a
+	}
+	xtfrm(ne + d * 2.1 + v)
+}
