@@ -38,7 +38,7 @@ gdal_write = function(x, ..., file, driver = "GTiff", options = character(0), ty
 		warning("handling scale_offset requires sf > 1.0-9")
 	d = stars::st_dimensions(x)
 	xydims = attr(d, "raster")$dimensions
-	if (!all.equal(match(xydims, names(d)), 1:2))
+	if (!isTRUE(all.equal(match(xydims, names(d)), 1:2)))
 		stop("x and y raster dimensions need to be in place 1 and 2")
 	from = c(d[[1]]$from, d[[2]]$from) - 1
 	dims = c(d[[1]]$to, d[[2]]$to)
@@ -410,3 +410,12 @@ gdal_addo = function(file, overviews = c(2,4,8,16), method = "NEAREST", layers =
 	invisible(CPL_gdaladdo(file, method, as.integer(overviews), as.integer(layers), as.character(options), 
 				 config_options, as.logical(clean)[1], as.logical(read_only)[1]))
 }
+
+#' List GDAL compressors and decompressors
+#'
+#' List GDAL compressors and decompressors
+#' @return named list with two character vectors, containing compressors and decompressors
+#' @export
+gdal_compressors = function() {
+	CPL_compressors()
+}
