@@ -9,6 +9,10 @@
 #include <cpl_conv.h>
 #include <cpl_string.h>
 
+#if GDAL_VERSION_NUM >= 3040000
+#include <cpl_compressor.h>
+#endif
+
 #include <stdlib.h> // atoi
 #include <string.h>
 
@@ -67,7 +71,7 @@ void unset_error_handler(void)
     CPLSetErrorHandler((CPLErrorHandler)__err_silent);
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 void CPL_gdal_init()
 {
     CPLSetErrorHandler((CPLErrorHandler)__err_handler);
@@ -77,7 +81,7 @@ void CPL_gdal_init()
 }
 
 // #nocov start
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 void CPL_gdal_cleanup_all()
 {
     OGRCleanupAll();
@@ -85,7 +89,7 @@ void CPL_gdal_cleanup_all()
 }
 // #nocov end
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 const char* CPL_gdal_version(const char* what = "RELEASE_NAME")
 {
 	return GDALVersionInfo(what);
@@ -193,7 +197,7 @@ OGRSpatialReference *OGRSrs_from_crs(Rcpp::List crs) {
 	return dest;
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::List CPL_crs_parameters(Rcpp::List crs) {
 
 	char *cp = NULL;
@@ -203,8 +207,8 @@ Rcpp::List CPL_crs_parameters(Rcpp::List crs) {
 	if (srs == NULL)
 		Rcpp::stop("crs not found"); // #nocov
 
-	Rcpp::List out(16);
-	Rcpp::CharacterVector names(16);
+	Rcpp::List out(17);
+	Rcpp::CharacterVector names(17);
 	out(0) = Rcpp::NumericVector::create(srs->GetSemiMajor());
 	names(0) = "SemiMajor";
 
@@ -346,6 +350,18 @@ Rcpp::List CPL_crs_parameters(Rcpp::List crs) {
 		Rcpp::_["orientation"] = orientation);
 	out(15) = axes_df;
 	names(15) = "axes";
+	// base GEOGCRS: https://github.com/r-spatial/sf/issues/2524
+	OGRSpatialReference *base_srs = new OGRSpatialReference;
+	if (base_srs->CopyGeogCSFrom(srs) == OGRERR_NONE) {
+		if (base_srs->exportToWkt(&cp) == OGRERR_NONE) {
+			out(16) = Rcpp::CharacterVector::create(cp);
+			CPLFree(cp);
+		} else
+			out(16) = Rcpp::CharacterVector::create(NA_STRING);
+	} else 
+		out(16) = Rcpp::CharacterVector::create(NA_STRING);
+	names(16) = "gcs_crs";
+	delete base_srs;
 
 	set_error_handler();
 
@@ -370,7 +386,7 @@ int srid_from_crs(Rcpp::List crs) {
 	return(ret_val);
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::LogicalVector CPL_crs_equivalent(Rcpp::List crs1, Rcpp::List crs2) {
 
 	OGRSpatialReference *srs1 = OGRSrs_from_crs(crs1);
@@ -444,7 +460,7 @@ std::vector<char *> create_options(Rcpp::CharacterVector lco, bool quiet) {
 }
 
 // convert NULL-terminated array of strings to Rcpp::CharacterVector
-Rcpp::CharacterVector charpp2CV(char **cp) {
+Rcpp::CharacterVector charpp2CV(CSLConstList cp) {
 	int n = 0;
 	while (cp && cp[n] != NULL)
 		n++; // count
@@ -504,7 +520,7 @@ Rcpp::List sfc_from_ogr(std::vector<OGRGeometry *> g, bool destroy = false) {
 	return ret;
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::List CPL_crs_from_input(Rcpp::CharacterVector input) {
 	OGRSpatialReference *ref = new OGRSpatialReference;
 	handle_axis_order(ref);
@@ -519,7 +535,7 @@ Rcpp::List CPL_crs_from_input(Rcpp::CharacterVector input) {
 	return crs;
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::List CPL_roundtrip(Rcpp::List sfc) { // for debug purposes
 	std::vector<OGRGeometry *> g = ogr_from_sfc(sfc, NULL);
 	for (size_t i = 0; i < g.size(); i++) {
@@ -531,7 +547,7 @@ Rcpp::List CPL_roundtrip(Rcpp::List sfc) { // for debug purposes
 	return sfc_from_ogr(g, true); // destroys g;
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::List CPL_circularstring_to_linestring(Rcpp::List sfc) { // need to pass more parameters?
 	std::vector<OGRGeometry *> g = ogr_from_sfc(sfc, NULL);
 	std::vector<OGRGeometry *> out(g.size());
@@ -543,7 +559,7 @@ Rcpp::List CPL_circularstring_to_linestring(Rcpp::List sfc) { // need to pass mo
 	return sfc_from_ogr(out, true); // destroys out;
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::List CPL_multisurface_to_multipolygon(Rcpp::List sfc) { // need to pass more parameters?
 	std::vector<OGRGeometry *> g = ogr_from_sfc(sfc, NULL);
 	std::vector<OGRGeometry *> out(g.size());
@@ -560,7 +576,7 @@ Rcpp::List CPL_multisurface_to_multipolygon(Rcpp::List sfc) { // need to pass mo
 	return sfc_from_ogr(out, true); // destroys out;
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::List CPL_compoundcurve_to_linear(Rcpp::List sfc) { // need to pass more parameters?
 	std::vector<OGRGeometry *> g = ogr_from_sfc(sfc, NULL);
 	std::vector<OGRGeometry *> out(g.size());
@@ -572,7 +588,7 @@ Rcpp::List CPL_compoundcurve_to_linear(Rcpp::List sfc) { // need to pass more pa
 	return sfc_from_ogr(out, true); // destroys out;
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::List CPL_curve_to_linestring(Rcpp::List sfc) { // need to pass more parameters? #nocov start
 	std::vector<OGRGeometry *> g = ogr_from_sfc(sfc, NULL);
 	std::vector<OGRGeometry *> out(g.size());
@@ -583,7 +599,7 @@ Rcpp::List CPL_curve_to_linestring(Rcpp::List sfc) { // need to pass more parame
 	return sfc_from_ogr(out, true); // destroys out;
 } // #nocov end
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::LogicalVector CPL_can_transform(Rcpp::List src, Rcpp::List dst) {
 	if (src.size() != 2 || dst.size() != 2)
 		return false;
@@ -605,7 +621,7 @@ Rcpp::LogicalVector CPL_can_transform(Rcpp::List src, Rcpp::List dst) {
 		return false;
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::List CPL_transform(Rcpp::List sfc, Rcpp::List crs,
 		Rcpp::NumericVector AOI, Rcpp::CharacterVector pipeline, bool reverse = false,
 		double desired_accuracy = -1.0, bool allow_ballpark = true) {
@@ -674,7 +690,7 @@ Rcpp::List CPL_transform(Rcpp::List sfc, Rcpp::List crs,
 	return ret;
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::NumericVector CPL_transform_bounds(Rcpp::NumericVector bb, Rcpp::List crs_dst,
 		int densify_pts = 21) {
 
@@ -722,7 +738,7 @@ Rcpp::NumericVector CPL_transform_bounds(Rcpp::NumericVector bb, Rcpp::List crs_
 	return ret;
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::List CPL_wrap_dateline(Rcpp::List sfc, Rcpp::CharacterVector opt, bool quiet = true) {
 
 	std::vector <char *> options = create_options(opt, quiet);
@@ -735,7 +751,7 @@ Rcpp::List CPL_wrap_dateline(Rcpp::List sfc, Rcpp::CharacterVector opt, bool qui
 	return sfc_from_ogr(ret, true); // destroys ret;
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::List CPL_get_gdal_drivers(int dummy) {
 
 	int ndr = GetGDALDriverManager()->GetDriverCount();
@@ -766,7 +782,7 @@ Rcpp::List CPL_get_gdal_drivers(int dummy) {
 		Rcpp::Named("vsi") = vsi_attr);
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::List CPL_sfc_from_wkt(Rcpp::CharacterVector wkt) {
 	std::vector<OGRGeometry *> g(wkt.size());
 	OGRGeometryFactory f;
@@ -781,13 +797,13 @@ Rcpp::List CPL_sfc_from_wkt(Rcpp::CharacterVector wkt) {
 	return sfc_from_ogr(g, true);
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::LogicalVector CPL_gdal_with_geos() {
 	bool withGEOS = OGRGeometryFactory::haveGEOS();
 	return Rcpp::LogicalVector::create(withGEOS);
 }
 
-// [[Rcpp::export]]
+// [[Rcpp::export(rng=false)]]
 Rcpp::LogicalVector CPL_axis_order_authority_compliant(Rcpp::LogicalVector authority_compliant) {
 	if (authority_compliant.size() > 1)
 		Rcpp::stop("argument authority_compliant should have length 0 or 1"); // #nocov
@@ -812,3 +828,28 @@ OGRSpatialReference *handle_axis_order(OGRSpatialReference *sr) {
 #endif
 	return sr;
 }
+
+Rcpp::CharacterVector to_cv(char **cpp) {
+	Rcpp::CharacterVector cv;
+	for (int i = 0; cpp[i] != NULL; i++)
+		cv.push_back(cpp[i]);
+	CSLDestroy(cpp);
+	return cv;
+}
+
+#if GDAL_VERSION_NUM >= 3040000
+// [[Rcpp::export(rng=false)]]
+Rcpp::List CPL_compressors() {
+	Rcpp::CharacterVector compressors =   to_cv(CPLGetCompressors());
+	Rcpp::CharacterVector decompressors = to_cv(CPLGetDecompressors());
+	return Rcpp::List::create(
+			Rcpp::_["compressors"] = compressors,
+			Rcpp::_["decompressors"] = decompressors
+		);
+}
+#else
+Rcpp::CharacterVector CPL_compressors() {
+	Rcpp::stop("CPL_compressors() requires GDAL >= 3.4\n");
+	return Rcpp::NumericVector::create(0);
+}
+#endif
