@@ -1,2 +1,5 @@
+#ifndef SF_HEX_H_
+#define SF_HEX_H_
 Rcpp::List CPL_hex_to_raw(Rcpp::CharacterVector cx);
 Rcpp::CharacterVector CPL_raw_to_hex(Rcpp::RawVector raw);
+#endif // SF_HEX_H_
